@@ -1,19 +1,22 @@
-# 
+#
 # This file is part of Module-Packaged-Generator
-# 
+#
 # This software is copyright (c) 2010 by Jerome Quelin.
-# 
+#
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
-# 
+#
 use 5.008;
 use strict;
 use warnings;
 
 package Module::Packaged::Generator::Distribution;
-our $VERSION = '1.100240';
+BEGIN {
+  $Module::Packaged::Generator::Distribution::VERSION = '1.111040';
+}
 # ABSTRACT: base class for all distribution drivers
 
+
 # -- public methods
 
 
@@ -34,7 +37,7 @@ Module::Packaged::Generator::Distribution - base class for all distribution driv
 
 =head1 VERSION
 
-version 1.100240
+version 1.111040
 
 =head1 DESCRIPTION
 
@@ -44,18 +47,22 @@ dying, since they should be overridden in the sub-classes.
 
 =head1 METHODS
 
-=head2 my $bool = $class->match;
+=head2 match
+
+    my $bool = $class->match;
 
 Return true if the class has detected that it can provides information
 on the current machine.
 
-=head2 my @modules = $class->list;
+=head2 list
+
+    my @modules = $class->list;
 
 Return the list of available Perl modules for this distribution.
 
 =head1 AUTHOR
 
-  Jerome Quelin
+Jerome Quelin
 
 =head1 COPYRIGHT AND LICENSE
 
